pub fn inspect_backup(
options: &BackupInspectOptions,
) -> Result<BackupInspectionReport, BackupCommandError>Expand description
Inspect manifest and journal agreement without reading artifact bytes.
pub fn inspect_backup(
options: &BackupInspectOptions,
) -> Result<BackupInspectionReport, BackupCommandError>Inspect manifest and journal agreement without reading artifact bytes.