Module list

Module list 

Structs

ListOptions
ListOptions
ListTitle
ListTitle

Enums

ListCommandError
ListCommandError
ListSource
ListSource
ReadyStatus
ReadyStatus

Functions

render_list_output
Render a named list view with a fleet/source title above the registry table.
render_registry_tree
Render all registry entries, or one selected subtree, as a whitespace table.
run
Run a list subcommand or the default tree listing.