pub fn render_registry_tree(
registry: &[RegistryEntry],
canister: Option<&str>,
) -> Result<String, ListCommandError>Expand description
Render all registry entries, or one selected subtree, as an ASCII tree.
pub fn render_registry_tree(
registry: &[RegistryEntry],
canister: Option<&str>,
) -> Result<String, ListCommandError>Render all registry entries, or one selected subtree, as an ASCII tree.