pub fn run<I>(args: I) -> Result<(), ListCommandError>where
I: IntoIterator<Item = OsString>,Expand description
Run a list subcommand or the default tree listing.
pub fn run<I>(args: I) -> Result<(), ListCommandError>where
I: IntoIterator<Item = OsString>,Run a list subcommand or the default tree listing.