Module restore

Module restore 

Structs

RestoreApplyOptions
RestoreApplyOptions
RestorePlanOptions
RestorePlanOptions
RestoreRunOptions
RestoreRunOptions

Enums

RestoreCommandError
RestoreCommandError

Functions

plan_restore
Build a no-mutation restore plan from a manifest and optional mapping.
restore_apply_dry_run
Build a no-mutation restore apply dry-run from a restore plan.
restore_run_dry_run
Build a no-mutation native restore runner preview from a journal file.
restore_run_unclaim_pending
Recover an interrupted restore runner by unclaiming the pending operation.
run
Run a restore subcommand.