pub fn plan_restore(
options: &RestorePlanOptions,
) -> Result<RestorePlan, RestoreCommandError>Expand description
Build a no-mutation restore plan from a manifest and optional mapping.
pub fn plan_restore(
options: &RestorePlanOptions,
) -> Result<RestorePlan, RestoreCommandError>Build a no-mutation restore plan from a manifest and optional mapping.