pub fn restore_apply_next(
options: &RestoreApplyNextOptions,
) -> Result<RestoreApplyNextOperation, RestoreCommandError>Expand description
Build the next restore apply operation response from a journal file.
pub fn restore_apply_next(
options: &RestoreApplyNextOptions,
) -> Result<RestoreApplyNextOperation, RestoreCommandError>Build the next restore apply operation response from a journal file.