pub fn restore_run_execute(
options: &RestoreRunOptions,
) -> Result<RestoreRunResponse, RestoreCommandError>Expand description
Execute ready restore apply journal operations through generated runner commands.
pub fn restore_run_execute(
options: &RestoreRunOptions,
) -> Result<RestoreRunResponse, RestoreCommandError>Execute ready restore apply journal operations through generated runner commands.