Structs
- List
Options - ListOptions
- List
Title - ListTitle
Enums
- List
Command Error - ListCommandError
- List
Source - ListSource
- Ready
Status - ReadyStatus
Functions
- render_
list_ output - Render a named list view with a fleet/source title above the registry table.
- render_
registry_ tree - Render all registry entries, or one selected subtree, as a whitespace table.
- run
- Run a list subcommand or the default tree listing.