Structs
- Restore
Apply Claim Options - RestoreApplyClaimOptions
- Restore
Apply Command Options - RestoreApplyCommandOptions
- Restore
Apply Mark Options - RestoreApplyMarkOptions
- Restore
Apply Next Options - RestoreApplyNextOptions
- Restore
Apply Options - RestoreApplyOptions
- Restore
Apply Report Options - RestoreApplyReportOptions
- Restore
Apply Status Options - RestoreApplyStatusOptions
- Restore
Apply Unclaim Options - RestoreApplyMarkOptions
- Restore
Plan Options - RestorePlanOptions
- Restore
RunOptions - RestoreRunOptions
- Restore
RunResponse - RestoreRunResponse
- Restore
Status Options - RestoreStatusOptions
Enums
- Restore
Apply Mark State - RestoreApplyMarkState
- Restore
Command Error - RestoreCommandError
Functions
- plan_
restore - Build a no-mutation restore plan from a manifest and optional mapping.
- restore_
apply_ claim - Mark the next restore apply journal operation pending.
- restore_
apply_ command - Build the next restore apply command preview from a journal file.
- restore_
apply_ dry_ run - Build a no-mutation restore apply dry-run from a restore plan.
- restore_
apply_ mark - Mark one restore apply journal operation completed or failed.
- restore_
apply_ next - Build the next restore apply operation response from a journal file.
- restore_
apply_ report - Build an operator-oriented restore apply report from a journal file.
- restore_
apply_ status - Build a compact restore apply status from a journal file.
- restore_
apply_ unclaim - Mark the current pending restore apply journal operation ready again.
- restore_
run_ dry_ run - Build a no-mutation native restore runner preview from a journal file.
- restore_
run_ execute - Execute ready restore apply journal operations through generated runner commands.
- restore_
run_ unclaim_ pending - Recover an interrupted restore runner by unclaiming the pending operation.
- restore_
status - Build the initial no-mutation restore status from a restore plan.
- run
- Run a restore subcommand.