Module restore

Module restore 

Structs

RestoreApplyClaimOptions
RestoreApplyClaimOptions
RestoreApplyCommandOptions
RestoreApplyCommandOptions
RestoreApplyMarkOptions
RestoreApplyMarkOptions
RestoreApplyNextOptions
RestoreApplyNextOptions
RestoreApplyOptions
RestoreApplyOptions
RestoreApplyReportOptions
RestoreApplyReportOptions
RestoreApplyStatusOptions
RestoreApplyStatusOptions
RestoreApplyUnclaimOptions
RestoreApplyMarkOptions
RestorePlanOptions
RestorePlanOptions
RestoreRunOptions
RestoreRunOptions
RestoreRunResponse
RestoreRunResponse
RestoreStatusOptions
RestoreStatusOptions

Enums

RestoreApplyMarkState
RestoreApplyMarkState
RestoreCommandError
RestoreCommandError

Functions

plan_restore
Build a no-mutation restore plan from a manifest and optional mapping.
restore_apply_claim
Mark the next restore apply journal operation pending.
restore_apply_command
Build the next restore apply command preview from a journal file.
restore_apply_dry_run
Build a no-mutation restore apply dry-run from a restore plan.
restore_apply_mark
Mark one restore apply journal operation completed or failed.
restore_apply_next
Build the next restore apply operation response from a journal file.
restore_apply_report
Build an operator-oriented restore apply report from a journal file.
restore_apply_status
Build a compact restore apply status from a journal file.
restore_apply_unclaim
Mark the current pending restore apply journal operation ready again.
restore_run_dry_run
Build a no-mutation native restore runner preview from a journal file.
restore_run_execute
Execute ready restore apply journal operations through generated runner commands.
restore_run_unclaim_pending
Recover an interrupted restore runner by unclaiming the pending operation.
restore_status
Build the initial no-mutation restore status from a restore plan.
run
Run a restore subcommand.