Structs
- Restore
Apply Options - RestoreApplyOptions
- Restore
Apply Status Options - RestoreApplyStatusOptions
- Restore
Plan Options - RestorePlanOptions
- Restore
Status Options - RestoreStatusOptions
Enums
- Restore
Command Error - RestoreCommandError
Functions
- plan_
restore - Build a no-mutation restore plan from a manifest and optional mapping.
- restore_
apply_ dry_ run - Build a no-mutation restore apply dry-run from a restore plan.
- restore_
apply_ status - Build a compact restore apply status from a journal file.
- restore_
status - Build the initial no-mutation restore status from a restore plan.
- run
- Run a restore subcommand.